==> ciao-4.6-src-core.tar.gz: ciao-4.6/src/config/ipython_cxc.py <==
# 
#  Copyright (C) 2012  Smithsonian Astrophysical Observatory
#
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 3 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License along
#  with this program; if not, write to the Free Software Foundation, Inc.,
#  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#

# IPYTHON_CXC_VERSION 40201

import os
import sys
import IPython.core.interactiveshell
import traceback as _tb_ 

__all__ = ["script", "init"]


# get the interactive shell
_ishell_ = IPython.core.interactiveshell.InteractiveShell ().instance ()

# create a tracebacklimit member to sys to specify the 
# number of tracebacks displayed with an error 
# initialize to zero for no traceback
if hasattr(sys, "tracebacklimit") is False:
   sys.tracebacklimit = 0 


#try:
#   if __ciao_app_name__:
#      pass
#except:
#   __ciao_app_name__ = ''
__ciao_app_name__ = ''

def ciao_exception_handler(self, type, value, traceback, tb_offset=None):
    if (sys.tracebacklimit > 0):
       _tb_.print_tb(traceback, sys.tracebacklimit) 
    if str(value).find('chips ') == 0:
       print >> sys.stderr, '%s' % (value,)
    else:
       print >> sys.stderr, '%s: %s' % (type.__name__, value)
    return _tb_.format_exc (traceback)

_ishell_.set_custom_exc((Exception,), ciao_exception_handler)

## If readline.clear_history() undefined, add a no-op
## IPython is supposed to do so itself, doesn't as of 0.8.0.
#if hasattr(IPython.iplib.readline, "clear_history") is False:
#   def clear_history():
#      pass
#   IPython.iplib.readline.clear_history = clear_history

def script(filename=None, clobber=False):

   if filename is None:
      filename = __ciao_app_name__.lower ()+".log"
   
   if os.path.isfile(filename) and not clobber:
      raise IOError("script file %s exists and clobber is not set." % filename)

   hist = _ishell_.history_manager.input_hist_parsed
   cmd = _ishell_.find_user_code ('0:{0}'.format (len(hist)-1), False)

   fp = file(filename,"w")

   # remove the last line -- it's a call to the script function
   fp.write(cmd)
   fp.close()

__script_doc_template__ = """
   script

   SYNOPSIS
      Save {0} session commands to file

   SYNTAX

   Arguments:
      filename  - script filename
                  default = '{1}.log'
      clobber   - clobber file flag
                  default = False

   Returns:
      None

   DESCRIPTION
      Save {0} commands from current session to a script file.

   SEE ALSO
      save
"""
script.__doc__ = __script_doc_template__.format(__ciao_app_name__, __ciao_app_name__.lower())

def init (ciao_app_name = ''):
   __ciao_app_name__ = ciao_app_name
   script.__doc__ = __script_doc_template__.format(__ciao_app_name__, __ciao_app_name__.lower())

   # initialize the readline history for the current profile. With 
   # IPython 0.12, the readline history is defaulting to default profile 
   # even if you're in a different profile. Refilling the history fixes 
   # this. To test this in later versions, comment out the following 
   # start a session under a profile (e.g. chips or sherpa), run a few
   # commands, exit the session, start a new sesssion and hit the up
   # arrow. You should see the history from the previous session
   _ishell_.refill_readline_hist()

==> ciao-4.8-src-core.tar.gz: ciao-4.8/src/config/ipython_cxc.py <==
# 
#  Copyright (C) 2012,2015  Smithsonian Astrophysical Observatory
#
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 3 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License along
#  with this program; if not, write to the Free Software Foundation, Inc.,
#  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#


import os
import sys
import IPython.core.interactiveshell
import traceback as _tb_ 

__all__ = ["script", "init"]

# Fix for #14096 CIAO is no longer in the path from within ipython
os.environ["SHELL"]="/bin/sh"

# get the interactive shell
# OL: after upgrading ipython from 1.x to 2.x we ha
_ishell_ = IPython.core.interactiveshell.InteractiveShell.instance()

# create a tracebacklimit member to sys to specify the 
# number of tracebacks displayed with an error 
# initialize to zero for no traceback
if hasattr(sys, "tracebacklimit") is False:
   sys.tracebacklimit = 0 

try:
   import ciao_version as cv
except ImportError:
   import warnings
   warnings.warn("Unable to load the ciao_version module to determine version number- defaulting %s version to 0.0.0"%__name__, Warning)
   __version__ = "0.0.0"
else:
   __version__ = cv.get_ciao_version()



#try:
#   if __ciao_app_name__:
#      pass
#except:
#   __ciao_app_name__ = ''
__ciao_app_name__ = ''

def ciao_exception_handler(self, type, value, traceback, tb_offset=None):
    if (sys.tracebacklimit > 0):
       _tb_.print_tb(traceback, sys.tracebacklimit) 
    if str(value).find('chips ') == 0:
       print >> sys.stderr, '%s' % (value,)
    else:
       print >> sys.stderr, '%s: %s' % (type.__name__, value)
    return _tb_.format_exc (traceback)

_ishell_.set_custom_exc((Exception, KeyboardInterrupt), ciao_exception_handler)

## If readline.clear_history() undefined, add a no-op
## IPython is supposed to do so itself, doesn't as of 0.8.0.
#if hasattr(IPython.iplib.readline, "clear_history") is False:
#   def clear_history():
#      pass
#   IPython.iplib.readline.clear_history = clear_history

def script(filename=None, clobber=False):

   if filename is None:
      filename = __ciao_app_name__.lower ()+".log"
   
   if os.path.isfile(filename) and not clobber:
      raise IOError("script file %s exists and clobber is not set." % filename)

   hist = _ishell_.history_manager.input_hist_parsed
   cmd = _ishell_.find_user_code ('0:{0}'.format (len(hist)-1), False)

   fp = file(filename,"w")

   # remove the last line -- it's a call to the script function
   fp.write(cmd)
   fp.close()

__script_doc_template__ = """
   script

   SYNOPSIS
      Save {0} session commands to file

   SYNTAX

   Arguments:
      filename  - script filename
                  default = '{1}.log'
      clobber   - clobber file flag
                  default = False

   Returns:
      None

   DESCRIPTION
      Save {0} commands from current session to a script file.

   SEE ALSO
      save
"""
script.__doc__ = __script_doc_template__.format(__ciao_app_name__, __ciao_app_name__.lower())

def init (ciao_app_name = ''):
   __ciao_app_name__ = ciao_app_name
   script.__doc__ = __script_doc_template__.format(__ciao_app_name__, __ciao_app_name__.lower())

   # initialize the readline history for the current profile. With 
   # IPython 0.12, the readline history is defaulting to default profile 
   # even if you're in a different profile. Refilling the history fixes 
   # this. To test this in later versions, comment out the following 
   # start a session under a profile (e.g. chips or sherpa), run a few
   # commands, exit the session, start a new sesssion and hit the up
   # arrow. You should see the history from the previous session
   _ishell_.refill_readline_hist()
